@@ -5,4 +5,8 @@ from severino.sdk.mail_carrier import MailCarrier, MailCarrierTemplate
 from severino.sdk.reports_of_pcds_in_admission import ReminderReportsOfPcdsInAdmission
 from severino.sdk.rescission_workflow import RescissionWorkflow
 from severino.sdk.store_data import StoreData, StoreDataTmp
-from severino.sdk.vagas_dot_com import VagasDotComBot, VagasDotComCandidateMigration
+from severino.sdk.vagas_dot_com import (
+    VagasDotComBot,
+    VagasDotComCandidateGHLoad,
+    VagasDotComCandidateMigration,
+)
